@@ -3,7 +3,7 @@ use strict;
 use warnings;
 require 5.010;
 
-our $VERSION = '0.3.0';
+our $VERSION = '0.3.1';
 
 use Pod::Simple::Pandoc;
 use Pod::Pandoc::Modules;
@@ -24,6 +24,7 @@ Pod::Pandoc - process Plain Old Documentation format with Pandoc
 [![Coverage Status](https://coveralls.io/repos/nichtich/Pod-Pandoc/badge.svg)](https://coveralls.io/r/nichtich/Pod-Pandoc)
 [![Kwalitee Score](http://cpants.cpanauthors.org/dist/Pod-Pandoc.png)](http://cpants.cpanauthors.org/dist/Pod-Pandoc)
 [![Code Climate Issue Count](https://codeclimate.com/github/nichtich/Pod-Pandoc/badges/issue_count.svg)](https://codeclimate.com/github/nichtich/Pod-Pandoc)
+[![Documentation Status](https://readthedocs.org/projects/pod-pandoc/badge/?version=latest)](http://pod-pandoc.readthedocs.io/?badge=latest)
 
 =end markdown
 
@@ -60,6 +61,37 @@ L<Pod::Pandoc::Modules> holds a set of Pod documents of Perl modules
 
 =back
 
+=head1 EXAMPLES
+
+The L<GitHub wiki of this project|https://github.com/nichtich/Pod-Pandoc/wiki>
+is filled with wiki pages based on the documentation of each Perl module. The
+wiki pages are created with L<pod2pandoc> as following:
+
+  pod2pandoc lib/ script/ wiki/ --ext md --index Home --wiki -t markdown_github
+
+The documentation can be published in a similar way via GitHub pages (after
+enabling this feature in your repository setting):
+
+  pod2pandoc lib/ script/ docs --ext md --wiki -t markdown_github
+
+For generation of documentation with Sphinx we need reStructureText format. The
+index file and a configuration file C<conf.py> need to be created manually.
+Links between files further need to be adjusted because Pandoc does not support
+wikilinks in rst output format:
+
+  pod2pandoc lib/ script/ docs/ --index 0 --ext rst --wiki -t rst --standalone
+  cd docs
+  perl -pi -e 's/`([^`]+) <([^>]+)>`__/-e "$2.rst" ? ":doc:`$1 <$2>`" : "`$1 <$2>`__"/e' *.rst
+  cat toctree >> Pod-Pandoc.rst
+  make html
+
+The result is published at L<http://pod-pandoc.readthedocs.io/>.
+
+=head1 REQUIREMENTS
+
+Installation of this module does not require Pandoc but it is required to make
+actual use of it. See L<http://pandoc.org/installing.html> for installation.
+
 =head1 SEE ALSO
 
 This modules makes obsolete several specialized C<Pod::Simple::...> modules
